package pl.edu.pg.eti.kask.rpg.character.service.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import pl.edu.pg.eti.kask.rpg.character.entity.Character;
import pl.edu.pg.eti.kask.rpg.character.repository.api.CharacterRepository;
import pl.edu.pg.eti.kask.rpg.character.service.api.CharacterService;
import pl.edu.pg.eti.kask.rpg.user.entity.User;

import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Optional;
import java.util.UUID;

/**
 * Service layer for all business actions regarding character entity.
 */
@Service
public class CharacterDefaultService implements CharacterService {

    /**
     * Repository for character entity.
     */
    private final CharacterRepository repository;


    /**
     * @param repository repository for character entity
     */
    @Autowired
    public CharacterDefaultService(CharacterRepository repository) {
        this.repository = repository;
    }

    @Override
    public Optional<Character> find(UUID id) {
        return repository.findById(id);
    }

    @Override
    public Optional<Character> find(User user, UUID id) {
        return repository.findByIdAndUser(id, user);
    }


    @Override
    public List<Character> findAll() {
        return repository.findAll();
    }

    @Override
    public List<Character> findAll(User user) {
        return repository.findAllByUser(user);
    }


    @Override
    public void create(Character character) {
        repository.save(character);
    }

    @Override
    public void update(Character character) {
        repository.save(character);
    }

    @Override
    public void delete(UUID id) {
        repository.findById(id).ifPresent(repository::delete);
    }

    @Override
    public Optional<byte[]> findPortrait(UUID id) {
        return repository.findPortraitById(id);
    }

    @Override
    public void updatePortrait(UUID id, InputStream is) {
        repository.findById(id).ifPresent(character -> {
            try {
                character.setPortrait(is.readAllBytes());
                repository.save(character);
            } catch (IOException ex) {
                throw new IllegalStateException(ex);
            }
        });
    }

}
